<?xml version="1.0" encoding="UTF-8"?>
<?igorpro version="1.04"?>

<!-- This style sheet will load two waves, intensities1 and intensities2 -->
<!-- The first will have a wave note and the second will not -->
<!-- Otherwise, both waves will be exactly the same -->
<!-- It also creates one string list called xRayTube -->

<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<xsl:strip-space elements="*"/>
	<xsl:output method="html" indent="yes"/>

<xsl:template match="/">
	<body>
	<xsl:apply-templates/>

	[code]
	header += maincomment + sample
	header += measurementcomment + wavelength + startTime + endTime + author
	SetScale/I x,startPosition, endPosition, intensities1
	SetScale/I x,startPosition, endPosition, intensities2
	killvariables/Z startPosition, endPosition
	Note/NOCR intensities1, header
	killstrings/Z maincomment, sample, wavelength, measurementcomment
	killstrings/Z author, startTime, endTime, header
	[/code]
	
	</body>
</xsl:template>

<xsl:template match="*">
	<xsl:apply-templates/>
</xsl:template>

<xsl:template match="text()">
	<xsl:apply-templates/>
</xsl:template>
	
<xsl:template match="xrdMeasurements">
<div id="string">
	<p id="maincomment">\rMain Comment: <xsl:value-of select="comment/entry"/></p>
	<p id="sample">\rSample: <xsl:value-of select="sample/id"/> (<xsl:value-of select="sample/@type"/>)</p>
</div>
<xsl:apply-templates/>
</xsl:template>
	
<xsl:template match="xrdMeasurement">
<div id="string">
	<p id="measurementcomment">\rMeasurement Comment: <xsl:value-of select="comment/entry"/></p>
	<p id="wavelength">\rWavelength Used: <xsl:value-of select="usedWavelength/@intended"/> (<xsl:value-of select="usedWavelength/kAlpha1"/>, <xsl:value-of select="usedWavelength/kAlpha2"/>, <xsl:value-of select="usedWavelength/kBeta"/>)</p>
</div>
<xsl:apply-templates/>
</xsl:template>

<xsl:template match="xRayTube">
<ul id="xRayTube">
<li id="anode"><xsl:value-of select="anodeMaterial"/></li>
<li id="tension"><xsl:value-of select="tension"/> (<xsl:value-of select="tension/@unit"/>)</li>
<li id="current"><xsl:value-of select="current"/> (<xsl:value-of select="current/@unit"/>)</li>
</ul>
<xsl:apply-templates/>
</xsl:template>

<xsl:template match="scan/header">
<div id="string">
	<p id="startTime">\rStart Time: <xsl:value-of select="startTimeStamp"/> ... </p>
	<p id="endTime">End Time: <xsl:value-of select="endTimeStamp"/></p>
	<p id="author">\rAuthor: <xsl:value-of select="author"/></p>
	<p id="header">FILE HEADER\r--</p>
</div>
<xsl:apply-templates/>
</xsl:template>
	
<xsl:template match="scan/dataPoints">
<div id="variable">
	<p id="startPosition"><xsl:value-of select="positions/startPosition"/></p>
	<p id="endPosition"><xsl:value-of select="positions/endPosition"/></p>
</div>
<table id="row-vector">
<tr id="intensities1">
<td><xsl:value-of select="intensities"/></td>
</tr>
<tr id="intensities2">
<td><xsl:value-of select="intensities"/></td>
</tr>
</table>
</xsl:template>

</xsl:stylesheet>